@@ -7,10 +7,12 @@ from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric import padding
 from cryptography.hazmat.primitives.hashes import SHA256
 
+from spei import exceptions
+from spei.checksum.factory import get_checksum_generator
+from spei.errors import spei as errors
 from spei.requests import OrdenRequest
-from spei.resources import Orden
+from spei.resources import Orden, Respuesta
 from spei.responses import RespuestaResponse
-from spei.utils import format_data
 
 logger = logging.getLogger('spei')
 logger.setLevel(logging.DEBUG)
@@ -26,6 +28,7 @@ class BaseClient(object):
         password,
         verify=False,
         http_client=requests,
+        checksum_generator_factory=get_checksum_generator,
     ):
         self.priv_key = priv_key
         self.priv_key_passphrase = priv_key_passphrase or None
@@ -44,8 +47,12 @@ class BaseClient(object):
             default_backend(),
         )
 
+        self.checksum_generator_factory = checksum_generator_factory
+
     def generate_checksum(self, message_data):
-        message_as_bytes = format_data(message_data)
+        generator = self.checksum_generator_factory(message_data['op_tp_clave'])
+
+        message_as_bytes = generator.format_data(message_data)
 
         signed_message = self.pkey.sign(
             message_as_bytes,
@@ -68,4 +75,14 @@ class BaseClient(object):
         response = self.session.post(data=soap_request, url=self.host)
         logger.info(response.text)
         response.raise_for_status()
-        return respuesta_response_cls(response.text)
+        respuesta = respuesta_response_cls(response.text)
+        if respuesta.err_codigo != errors.GenericoCodigoError.exitoso:
+            self._raise_error(respuesta)
+        return respuesta
+
+    def _raise_error(self, respuesta: Respuesta):
+        if respuesta.err_codigo == errors.GenericoCodigoError.tipo_pago_invalido:
+            raise exceptions.TipoPagoInvalidoError(respuesta)
+        if respuesta.err_codigo == errors.OtrosCodigoError.otros_fecha_operacion_incorrecta:  # noqa: E501
+            raise exceptions.FechaOperacionIncorrectaError(respuesta)
+        raise exceptions.SPEIError(respuesta)
