@@ -1,9 +1,11 @@
 from spei.resources.acuse import (  # noqa: F401
     Acuse,
+    MensajeRespuesta,
     ResultadoBanxico,
     ResultadoServidor,
 )
 from spei.resources.cda import CDA  # noqa: F401
 from spei.resources.mensaje import Mensaje  # noqa: F401
-from spei.resources.orden import Orden, TerceroATercero  # noqa: F401
+from spei.resources.orden import Orden  # noqa: F401
+from spei.resources.payments import TerceroATercero  # noqa: F401
 from spei.resources.respuesta import Respuesta  # noqa: F401
